@@ -17,4 +17,4 @@ class Ling2MeRequest():
         
         json_response = json.loads(response.text)
 
-        return json_response['translated_text']
+        return json_response['data']['translated_text']
